"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.readPrismaDeclarations = void 0;
const promises_1 = __importDefault(require("fs/promises"));
const path_1 = __importDefault(require("path"));
const namespace_1 = require("../helpers/namespace");
async function readPrismaDeclarations(nsName) {
    const declaration = {};
    declaration.sourcePath = path_1.default.resolve(path_1.default.dirname(require.resolve('.prisma/client')), 'index.d.ts');
    // reads the file content
    declaration.content = await promises_1.default.readFile(declaration.sourcePath, 'utf-8');
    // creates a empty list of changes
    declaration.changeset = [];
    //  a 1   1 a
    //  s 2   2 s
    //  d 3   3 s <- (start: 1, end: 3, text: `s`) changed `s` to `ss` (start: 1, wide: 2)
    //    4   4 d
    //    5   5
    //  a 6   6
    //  s 7   7 a
    //  d 8   8 s
    //    9   9 d
    declaration.replacer = (start, end, text) => {
        // Adds a trailing space
        if (text[0] !== ' ') {
            text = ' ' + text;
        }
        for (const change of declaration.changeset) {
            if (start > change.start) {
                start += change.diff;
                end += change.diff;
            }
        }
        // replaces the file content at the correct position
        declaration.content =
            declaration.content.slice(0, start) + text + declaration.content.slice(end);
        // adds the change to the list
        declaration.changeset.push({ start, end, diff: start - end + text.length });
    };
    declaration.update = async () => {
        await promises_1.default.writeFile(declaration.sourcePath, (0, namespace_1.createNamespace)(nsName) + declaration.content);
    };
    return declaration;
}
exports.readPrismaDeclarations = readPrismaDeclarations;
//# sourceMappingURL=reader.js.map