﻿"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const generator_helper_1 = require("@prisma/generator-helper");
const typescript_1 = __importDefault(require("typescript"));
const reader_1 = require("./file/reader");
const module_1 = require("./handler/module");
const type_alias_1 = require("./handler/type-alias");
const dmmf_1 = require("./helpers/dmmf");
const { version } = require('../package.json');
(0, generator_helper_1.generatorHandler)({
    onManifest,
    onGenerate
});
function onManifest() {
    return {
        version,
        defaultOutput: './',
        prettyName: 'Prisma Generator Json Types',
        requiresGenerators: ['prisma-client-js']
    };
}
async function onGenerate(options) {
    const nsName = options.generator.config.namespace || 'PrismaJson';
    const { content, replacer, sourcePath, update } = await (0, reader_1.readPrismaDeclarations)(nsName);
    const tsSource = typescript_1.default.createSourceFile(sourcePath, content, typescript_1.default.ScriptTarget.ESNext, true, typescript_1.default.ScriptKind.TS);
    const models = (0, dmmf_1.parseDmmf)(options.dmmf);
    for (const child of tsSource.getChildren()) {
        switch (child.kind) {
            case typescript_1.default.SyntaxKind.TypeAliasDeclaration:
                await (0, type_alias_1.handleTypeAlias)(child, replacer, models, nsName);
                break;
            case typescript_1.default.SyntaxKind.ModuleDeclaration:
                await (0, module_1.handleModule)(child, replacer, models, nsName);
                break;
        }
    }
    await update();
}
//# sourceMappingURL=generator%20copy.js.map