"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleModule = void 0;
const sdk_1 = require("@prisma/sdk");
const typescript_1 = __importDefault(require("typescript"));
const regex_1 = require("../helpers/regex");
async function handleModule(module, replacer, models, nsName) {
    const namespace = module
        .getChildren()
        .find((n) => n.kind === typescript_1.default.SyntaxKind.ModuleBlock);
    if (!namespace) {
        sdk_1.logger.error('Prisma namespace could not be found');
        return;
    }
    for (const statement of namespace.statements) {
        const typeAlias = statement;
        // Filters any statement that isn't a export type declaration
        if (statement.kind !== typescript_1.default.SyntaxKind.TypeAliasDeclaration ||
            typeAlias.type.kind !== typescript_1.default.SyntaxKind.TypeLiteral) {
            continue;
        }
        const typeAliasName = typeAlias.name.getText();
        const typeAliasType = typeAlias.type;
        for (const model of models) {
            // May includes the model name but is not the actual model, like
            // UserCreateWithoutPostsInput for Post model. that's why we need
            // to check if the model name is in the regex
            if (!model.regexps.some((r) => r.test(typeAliasName))) {
                continue;
            }
            const fields = model.fields.filter((f) => f.documentation?.match(regex_1.JSON_REGEX));
            for (const member of typeAliasType.members) {
                if (member.kind !== typescript_1.default.SyntaxKind.PropertySignature) {
                    continue;
                }
                const signature = member;
                const fieldName = member.name?.getText();
                const field = fields.find((f) => f.name === fieldName);
                if (!field) {
                    continue;
                }
                if (!signature.type) {
                    throw new Error(`No type found for field ${fieldName} at model ${typeAliasName}`);
                }
                const typename = field.documentation?.match(regex_1.JSON_REGEX)?.[1];
                const signatureType = signature.type.getText();
                // TODO: JsonFilter and JsonWithAggregatesFilter
                switch (signatureType) {
                    case 'JsonValue':
                        replacer(signature.type.pos, signature.type.end, `${nsName}.${typename}`);
                        break;
                    case 'InputJsonValue':
                    case 'InputJsonValue | InputJsonValue':
                        replacer(signature.type.pos, signature.type.end, `DeepPartial<${nsName}.${typename}>`);
                        break;
                    // TODO
                    case 'JsonFilter':
                        break;
                    // TODO
                    case 'JsonWithAggregatesFilter':
                        break;
                    default:
                        sdk_1.logger.error(`Unknown type ${signatureType} for field ${fieldName} at model ${typeAliasName}`);
                }
            }
            // There is no need to continue the loop
            // as only ONE model may match
            break;
        }
    }
}
exports.handleModule = handleModule;
//# sourceMappingURL=module.js.map