"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleTypeAlias = void 0;
const sdk_1 = require("@prisma/sdk");
const typescript_1 = __importDefault(require("typescript"));
const regex_1 = require("../helpers/regex");
async function handleTypeAlias(type, replacer, models, nsName) {
    // enum declarations
    if (type.getChildAt(4)?.getText().startsWith('(typeof')) {
        return;
    }
    const name = type.name.getText();
    const model = models.find((m) => m.name === name);
    // not a model with typed json fields
    if (!model) {
        return;
    }
    const fields = model.fields.filter((f) => f.documentation?.match(regex_1.JSON_REGEX));
    const object = type.type;
    // not a type literal. TODO: there is a way of this happen?
    if (object.kind !== typescript_1.default.SyntaxKind.TypeLiteral) {
        sdk_1.logger.error(`Provided object is not a type literal: ${object.getText()}`);
        return;
    }
    for (const member of object.members) {
        for (const field of fields) {
            if (member.name?.getText() !== field.name) {
                continue;
            }
            const typename = field.documentation?.match(regex_1.JSON_REGEX)?.[1];
            replacer(member.type.pos, member.type.end, `${nsName}.${typename}`);
        }
    }
}
exports.handleTypeAlias = handleTypeAlias;
//# sourceMappingURL=type-alias.js.map