"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.onGenerate = void 0;
const typescript_1 = __importDefault(require("typescript"));
const reader_1 = require("./file/reader");
const module_1 = require("./handler/module");
const type_alias_1 = require("./handler/type-alias");
const dmmf_1 = require("./helpers/dmmf");
async function onGenerate(options) {
    const nsName = options.generator.config.namespace || 'PrismaJson';
    const { content, replacer, sourcePath, update } = await (0, reader_1.readPrismaDeclarations)(nsName);
    const tsSource = typescript_1.default.createSourceFile(sourcePath, content, typescript_1.default.ScriptTarget.ESNext, true, typescript_1.default.ScriptKind.TS);
    const models = (0, dmmf_1.parseDmmf)(options.dmmf);
    const promises = [];
    tsSource.forEachChild((child) => {
        switch (child.kind) {
            case typescript_1.default.SyntaxKind.TypeAliasDeclaration:
                promises.push((0, type_alias_1.handleTypeAlias)(child, replacer, models, nsName));
                break;
            case typescript_1.default.SyntaxKind.ModuleDeclaration:
                promises.push((0, module_1.handleModule)(child, replacer, models, nsName));
                break;
        }
    });
    await Promise.all(promises);
    await update();
}
exports.onGenerate = onGenerate;
//# sourceMappingURL=on-generate.js.map